#
# spec file for package libqt5-qtvirtualkeyboard
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define qt5_snapshot 0

Name:           libqt5-qtvirtualkeyboard
Version:        5.12.7
Release:        bp153.1.17
Summary:        Qt 5 Virtual Keyboard
License:        GPL-3.0
Group:          Development/Libraries/X11
Url:            https://www.qt.io
%define base_name libqt5
%define real_version 5.12.7
%define so_version 5.12.7
%define tar_version qtvirtualkeyboard-everywhere-src-5.12.7
Source:         https://download.qt.io/official_releases/qt/5.12/%{real_version}/submodules/%{tar_version}.tar.xz
BuildRequires:  libQt5Gui-private-headers-devel >= %{version}
BuildRequires:  libQt5Core-private-headers-devel >= %{version}
BuildRequires:  pkgconfig(Qt5Qml) >= %{version}
BuildRequires:  pkgconfig(Qt5Quick) >= %{version}
BuildRequires:  pkgconfig(Qt5Svg) >= %{version}
%if %qt5_snapshot
#to create the forwarding headers
BuildRequires:  perl
%endif
BuildRequires:  xz
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(hunspell)
# Was part of the core before 5.12
Recommends:     %{name}-hunspell
%requires_ge libQtQuick5

%description
Qt is a set of libraries for developing applications.

This package contains a virtual keyboard.

%package -n libQt5VirtualKeyboard5
Summary:       Qt5 Virtual Keyboard library
Group:         System/Libraries

%description -n libQt5VirtualKeyboard5
Internal library used by Qt for providing Hunspell support.

%package examples
Summary:        Qt5 virtualkeyboard examples
Group:          Development/Libraries/X11

%description examples
Examples for libqt5-qtvirtualkeyboard module.

%package devel
Summary:        Qt Development Kit
Group:          Development/Libraries/X11
Requires:       %{name} = %{version}

%description devel
You need this package if you want to compile programs or plugins with
Qt Virtual Keyboard.

%package private-headers-devel
Summary:        Non-ABI stable API for the Qt5 Virtual Keyboard
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}
Requires:       libQt5Gui-private-headers-devel >= %{version}
Requires:       libQt5Core-private-headers-devel >= %{version}

%description private-headers-devel
This package provides private headers of libqt5-qtvirtualkeyboard that are
normally not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package hunspell
Summary:       Hunspell Plugin for the Qt5 Virtual Keyboard
# TODO!
Group:         System/Libraries
Requires:      %{name} = %{version}

%description hunspell
This package provides a hunspell spell checking plugin for the Qt Virtual Keyboard.

%package -n libQt5HunspellInputMethod5
Summary:       Qt5 Hunspell Input Method
Group:         System/Libraries

%description -n libQt5HunspellInputMethod5
Internal library used by Qt for providing Hunspell support.

%package -n libQt5HunspellInputMethod-private-headers-devel
Summary:        Non-ABI stable API for libQt5HunspellInputMethod
Group:          Development/Libraries/C and C++
Requires:       libQt5HunspellInputMethod5 = %{version}	
Requires:       %{name}-private-headers-devel = %{version}

%description -n libQt5HunspellInputMethod-private-headers-devel
This package provides private headers of libQt5HunspellInputMethod that are
normally not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%prep
%setup -q -n %{tar_version}

%build
%if %qt5_snapshot
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
%endif
# Only enable languages that don't force-include bundled 3rdparty libs
%qmake5 "CONFIG+=lang-ar_AR lang-da_DK lang-de_DE lang-en_GB lang-es_ES lang-fa_FA lang-fi_FI lang-fr_FR lang-hi_IN lang-it_IT lang-nb_NO lang-pl_PL lang-pt_PT lang-ro_RO lang-ru_RU lang-sv_SE"
%make_jobs

%install
%qmake5_install

# kill .la files
rm -f %{buildroot}%{_libqt5_libdir}/lib*.la

%post   -n libQt5VirtualKeyboard5 -p /sbin/ldconfig
%postun -n libQt5VirtualKeyboard5 -p /sbin/ldconfig
%post   -n libQt5HunspellInputMethod5 -p /sbin/ldconfig
%postun -n libQt5HunspellInputMethod5 -p /sbin/ldconfig

%files
%license LICENSE.*
%dir %{_libqt5_plugindir}/virtualkeyboard
%{_libqt5_plugindir}/platforminputcontexts/libqtvirtualkeyboardplugin.so
%{_libqt5_archdatadir}/qml/QtQuick/VirtualKeyboard/

%files -n libQt5VirtualKeyboard5
%license LICENSE.*
%{_libqt5_libdir}/libQt5VirtualKeyboard.so.*

%files devel
%license LICENSE.*
%exclude %{_libqt5_includedir}/QtVirtualKeyboard/%{so_version}
%{_libqt5_includedir}/QtVirtualKeyboard/
%{_libqt5_libdir}/cmake/Qt5VirtualKeyboard/
%{_libqt5_libdir}/cmake/Qt5Gui/Qt5Gui_QVirtualKeyboardPlugin.cmake
%{_libqt5_libdir}/libQt5VirtualKeyboard.prl
%{_libqt5_libdir}/libQt5VirtualKeyboard.so
%{_libqt5_libdir}/pkgconfig/Qt5VirtualKeyboard.pc
%{_libqt5_libdir}/qt5/mkspecs/modules/qt_lib_virtualkeyboard.pri

%files private-headers-devel
%license LICENSE.*
%{_libqt5_libdir}/qt5/mkspecs/modules/qt_lib_virtualkeyboard_private.pri
%{_libqt5_includedir}/QtVirtualKeyboard/%{so_version}/

%files hunspell
%license LICENSE.*
%{_libqt5_plugindir}/virtualkeyboard/libqtvirtualkeyboard_hunspell.so

%files -n libQt5HunspellInputMethod5
%license LICENSE.*
%{_libqt5_libdir}/libQt5HunspellInputMethod.so.*

%files -n libQt5HunspellInputMethod-private-headers-devel
%license LICENSE.*
# Private headers + non-private Version/Depends headers
%{_libqt5_includedir}/QtHunspellInputMethod/
%{_libqt5_libdir}/libQt5HunspellInputMethod.prl
%{_libqt5_libdir}/libQt5HunspellInputMethod.so
%{_libqt5_libdir}/qt5/mkspecs/modules/qt_lib_hunspellinputmethod_private.pri

%files examples
%license LICENSE.*
%{_libqt5_examplesdir}/

%changelog
* Fri Jan 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.12.7:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.12.7/?h=v5.12.7
* Thu Nov 14 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.12.6:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.12.6/?h=v5.12.6
* Thu Sep 12 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.12.5:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.12.5/?h=5.12.5
* Fri Jun 14 2019 fabian@ritter-vogt.de
- Update to 5.12.4:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.12.4/?h=5.12.4
* Thu Apr 18 2019 fabian@ritter-vogt.de
- Update to 5.12.3:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.12.3/?h=v5.12.3
* Thu Mar 14 2019 fabian@ritter-vogt.de
- Update to 5.12.2:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.12.2/?h=5.12.2
* Fri Feb  1 2019 fabian@ritter-vogt.de
- Update to 5.12.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.12.1/?h=v5.12.1
* Thu Dec 20 2018 Christophe Giboudeaux <christophe@krop.fr>
- Fix the libQt5HunspellInputMethod-private-headers-devel requirements.
* Thu Dec  6 2018 fabian@ritter-vogt.de
- Update to 5.12.0:
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.12.0/?h=v5.12.0
* Mon Dec  3 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc2:
  * New bugfix release
  * Only important bugfixes
- Changelog for Qt 5.12.0:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.12.0/?h=5.12.0
* Thu Nov 22 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc:
  * New bugfix release
  * No changelog available
* Thu Nov  8 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta4:
  * New bugfix release
  * No changelog available
* Fri Oct 26 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta3:
  * New bugfix release
  * No changelog available
* Wed Oct 17 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta1:
  * New bugfix release
  * No changelog available
* Tue Oct  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0-alpha:
  * New feature release
  * For more details please see:
  * http://wiki.qt.io/New_Features_in_Qt_5.12
  * Extension API added
  * hunspell support split into a (private) library and plugin
* Fri Sep 21 2018 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.11.2/?h=v5.11.2
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.11.1/?h=v5.11.1
* Tue May 22 2018 fabian@ritter-vogt.de
- Update to 5.11.0
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.11.0/?h=v5.11.0
* Tue May  8 2018 fabian@ritter-vogt.de
- Update to 5.11.0-rc
  * New bugfix release
  * No changelog available
* Mon Apr 23 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta4
  * New bugfix release
  * No changelog available
* Wed Apr 11 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta3
  * New bugfix release
  * No changelog available
* Wed Mar 28 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta2
  * New bugfix release
  * No changelog available
* Thu Mar  1 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta1
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.11.0-beta1/?h=v5.11.0-beta1
* Tue Feb 20 2018 fabian@ritter-vogt.de
- Update to 5.11.0-alpha
  * New feature release
  * For more details please see:
  * https://wiki.qt.io/New_Features_in_Qt_5.11
* Wed Feb 14 2018 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.10.1/?h=v5.10.1
* Thu Dec  7 2017 fabian@ritter-vogt.de
- Update to 5.10.0 final
  * New bugfix release
* Sun Dec  3 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 2
  * New bugfix release
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 1
  * New bugfix release
* Sat Nov 25 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details, see:
    http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/tree/dist/changes-5.9.3/?h=v5.9.3
* Wed Nov 15 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 4
- Contains bugfixes
* Thu Nov  2 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 3
- Contains bugfixes
* Mon Oct 30 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 2
- Contains bugfixes
* Mon Oct  9 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 1
- For more information visit:
    https://blog.qt.io/blog/2017/10/09/qt-5-10-beta-released/
* Sun Oct  8 2017 lbeltrame@kde.org
- Update to 5.9.2
  * For more details please see:
    https://blog.qt.io/blog/2017/10/06/qt-5-9-2-released/
* Mon Sep 25 2017 fabian@ritter-vogt.de
- Update to 5.10 Alpha 1:
  * Added the following keyboard layouts: Hebrew, Serbian, Hungarian, Czech, Croatian, Bulgarian, Greek, Estonian, and Dutch.
  * Added handwriting support for Farsi, Arabic, and CJK (Chinese/Japanese/Korean).
  * Added new component (InputModeKey) for input mode switch.
  * OpenWNN:
    + Fixed crash when pressing the space after entering a smiley.
    + Fixed and optimized OpenWNN engine
- For more information visit:
    https://blog.qt.io/blog/2017/09/13/qt-5-10-alpha-released/
* Sat Jul  1 2017 lbeltrame@kde.org
- Update to 5.9.1
  * For more details please see:
    http://blog.qt.io/blog/2017/06/30/qt-5-9-1-released/
* Wed May 31 2017 fabian@ritter-vogt.de
- Update to 5.9.0 final
* Wed May 24 2017 fabian@ritter-vogt.de
- Update to 5.9.0 RC:
  * For more details please see:
    http://lists.qt-project.org/pipermail/announce/2017-May/000115.html
    and https://wiki.qt.io/New_Features_in_Qt_5.9
* Mon Mar 20 2017 fabian@ritter-vogt.de
- Downgrade to 5.7.1 for factory submission
* Fri Feb 24 2017 fabian@ritter-vogt.de
- Add initial package, based on libqt5-qtgraphicaleffects
